@@ -32,7 +32,8 @@
 #ifndef CDDB_CUE_COMMON_H
 
 void splt_cc_put_filenames_from_tags(splt_state *state, int tracks, int *error,
-    const splt_tags *all_tags, int only_set_name_if_null);
+    const splt_tags *all_tags, int only_set_name_if_null,
+    int force_splitnumber_as_filenumber);
 
 #define CDDB_CUE_COMMON_H
 
