@@ -39,7 +39,7 @@ that is meant to be used directly are all in mp3splt.c.
 #include <errno.h>
 
 #ifdef __WIN32__
-#include <winsock.h>
+#include <winsock2.h>
 #else
 #include <netdb.h>
 #endif
@@ -256,6 +256,13 @@ char *splt_e_strerror(splt_state *state, splt_code error_code)
     case SPLT_FREEDB_ERROR_SITE:
       return splt_su_get_formatted_message(state,
           _(" freedb error: bad response from remote host"));
+    case SPLT_ERROR_INTERNAL_SHEET:
+      return splt_su_get_formatted_message(state,
+          _(" internal sheet error: no internal sheet or invalid sheet"));
+    case SPLT_ERROR_INTERNAL_SHEET_TYPE_NOT_SUPPORTED:
+      return splt_su_get_formatted_message(state,
+          _(" internal sheet error: internal sheet type not supported"));
+
       //
     case SPLT_DEWRAP_OK:
       return splt_su_get_formatted_message(state, _(" wrap split ok"));
@@ -437,6 +444,8 @@ char *splt_e_strerror(splt_state *state, splt_code error_code)
       return splt_su_get_formatted_message(state, _(" regular expression error: no match"));
     case SPLT_REGEX_OK:
       return splt_su_get_formatted_message(state, _(" regular expression ok"));
+    case SPLT_ERROR_NO_AUTO_ADJUST_FOUND:
+      return splt_su_get_formatted_message(state, _(" error: one of the splitpoints has not been auto-adjusted"));
   }
 
   return NULL;
