@@ -75,6 +75,9 @@ void splt_o_set_options_default_values(splt_state *state)
   state->options.cue_set_splitpoint_names_from_rem_name = SPLT_FALSE;
   state->options.cue_disable_cue_file_created_message = SPLT_FALSE;
   state->options.cue_cddb_add_tags_with_keep_original_tags = SPLT_FALSE;
+  state->options.warn_if_no_auto_adjust_found = SPLT_FALSE;
+  state->options.stop_if_no_auto_adjust_found = SPLT_FALSE;
+  state->options.decode_and_write_flac_md5sum = SPLT_FALSE;
   state->options.id3v2_encoding = SPLT_ID3V2_UTF16;
   state->options.input_tags_encoding = SPLT_ID3V2_UTF8;
   state->options.time_minimum_length = 0;
@@ -141,6 +144,15 @@ void splt_o_set_option(splt_state *state, int option_name, const void *data)
     case SPLT_OPT_CUE_CDDB_ADD_TAGS_WITH_KEEP_ORIGINAL_TAGS:
       state->options.cue_cddb_add_tags_with_keep_original_tags = *((int *)data);
       break;
+    case SPLT_OPT_WARN_IF_NO_AUTO_ADJUST_FOUND:
+      state->options.warn_if_no_auto_adjust_found = *((int *)data);
+      break;
+    case SPLT_OPT_STOP_IF_NO_AUTO_ADJUST_FOUND:
+      state->options.stop_if_no_auto_adjust_found = *((int *)data);
+      break;
+    case SPLT_OPT_DECODE_AND_WRITE_FLAC_MD5SUM_FOR_CREATED_FILES:
+      state->options.decode_and_write_flac_md5sum = *((int *)data);
+      break;
     case SPLT_OPT_ID3V2_ENCODING:
       state->options.id3v2_encoding = *((int *) data);
       break;
@@ -271,6 +283,12 @@ static void *splt_o_get_option(splt_state *state, int option_name)
       return &state->options.cue_disable_cue_file_created_message;
     case SPLT_OPT_CUE_CDDB_ADD_TAGS_WITH_KEEP_ORIGINAL_TAGS:
       return &state->options.cue_cddb_add_tags_with_keep_original_tags;
+    case SPLT_OPT_WARN_IF_NO_AUTO_ADJUST_FOUND:
+      return &state->options.warn_if_no_auto_adjust_found;
+    case SPLT_OPT_STOP_IF_NO_AUTO_ADJUST_FOUND:
+      return &state->options.stop_if_no_auto_adjust_found;
+    case SPLT_OPT_DECODE_AND_WRITE_FLAC_MD5SUM_FOR_CREATED_FILES:
+      return &state->options.decode_and_write_flac_md5sum;
     case SPLT_OPT_ID3V2_ENCODING:
       return &state->options.id3v2_encoding;
     case SPLT_OPT_INPUT_TAGS_ENCODING:
