@@ -412,8 +412,6 @@ static void splt_p_free_plugin_data(splt_plugin_data *pl_data)
 int splt_p_move_replace_plugin_data(splt_state *state, int old, int new)
 {
   splt_plugins *pl = state->plug;
-  fprintf(stdout, "move old %d to new %d\n", old, new);
-  fflush(stdout);
 
   splt_p_free_plugin_data(&pl->data[new]);
 
@@ -620,6 +618,8 @@ int splt_p_find_get_plugins_data(splt_state *state)
         lt_dlsym(pl->data[i].plugin_handle, "splt_pl_check_plugin_is_for_file");
       pl->data[i].func->splt_pl_search_syncerrors =
         lt_dlsym(pl->data[i].plugin_handle, "splt_pl_search_syncerrors");
+      pl->data[i].func->splt_pl_import_internal_sheets =
+        lt_dlsym(pl->data[i].plugin_handle, "splt_pl_import_internal_sheets");
       pl->data[i].func->splt_pl_dewrap =
         lt_dlsym(pl->data[i].plugin_handle, "splt_pl_dewrap");
       pl->data[i].func->splt_pl_offset_split =
@@ -799,6 +799,25 @@ void splt_p_dewrap(splt_state *state, int listonly, const char *dir, int *error)
   }
 }
 
+void splt_p_import_internal_sheets(splt_state *state, splt_code *error)
+{
+  splt_plugins *pl = state->plug;
+  int current_plugin = splt_p_get_current_plugin(state);
+  if ((current_plugin < 0) || (current_plugin >= pl->number_of_plugins_found))
+  {
+    *error = SPLT_ERROR_NO_PLUGIN_FOUND;
+    return;
+  }
+
+  if (pl->data[current_plugin].func->splt_pl_import_internal_sheets == NULL)
+  {
+    *error = SPLT_PLUGIN_ERROR_UNSUPPORTED_FEATURE;
+    return;
+  }
+
+  pl->data[current_plugin].func->splt_pl_import_internal_sheets(state, error);
+}
+
 double splt_p_split(splt_state *state, const char *final_fname, double begin_point,
     double end_point, int *error, int save_end_point)
 {
